@@ -1,18 +1,21 @@
 # frozen_string_literal: true
 
 require_relative 'helper'
-require_relative '../lib/rack/query_parser'
+
+separate_testing do
+  require_relative '../lib/rack/query_parser'
+end
 
 describe Rack::QueryParser do
   it "can normalize values with missing values" do
-    query_parser = Rack::QueryParser.make_default(Rack::Utils.key_space_limit, 8)
+    query_parser = Rack::QueryParser.make_default(8)
     query_parser.parse_nested_query("a=a").must_equal({"a" => "a"})
     query_parser.parse_nested_query("a=").must_equal({"a" => ""})
     query_parser.parse_nested_query("a").must_equal({"a" => nil})
   end
 
   it "accepts bytesize_limit to specify maximum size of query string to parse" do
-    query_parser = Rack::QueryParser.make_default(Rack::Utils.key_space_limit, 32, bytesize_limit: 3)
+    query_parser = Rack::QueryParser.make_default(32, bytesize_limit: 3)
     query_parser.parse_query("a=a").must_equal({"a" => "a"})
     query_parser.parse_nested_query("a=a").must_equal({"a" => "a"})
     query_parser.parse_nested_query("a=a", '&').must_equal({"a" => "a"})
@@ -22,19 +25,12 @@ describe Rack::QueryParser do
   end
 
   it "accepts params_limit to specify maximum number of query parameters to parse" do
-    query_parser = Rack::QueryParser.make_default(Rack::Utils.key_space_limit, 32, params_limit: 2)
+    query_parser = Rack::QueryParser.make_default(32, params_limit: 2)
     query_parser.parse_query("a=a&b=b").must_equal({"a" => "a", "b" => "b"})
     query_parser.parse_nested_query("a=a&b=b").must_equal({"a" => "a", "b" => "b"})
     query_parser.parse_nested_query("a=a&b=b", '&').must_equal({"a" => "a", "b" => "b"})
     proc { query_parser.parse_query("a=a&b=b&c=c") }.must_raise Rack::QueryParser::QueryLimitError
     proc { query_parser.parse_nested_query("a=a&b=b&c=c", '&') }.must_raise Rack::QueryParser::QueryLimitError
     proc { query_parser.parse_query("b[]=a&b[]=b&b[]=c") }.must_raise Rack::QueryParser::QueryLimitError
-
-    query_parser.parse_query("a=a;b=b").must_equal({"a" => "a", "b" => "b"})
-    query_parser.parse_nested_query("a=a;b=b").must_equal({"a" => "a", "b" => "b"})
-    query_parser.parse_nested_query("a=a;b=b", ';').must_equal({"a" => "a", "b" => "b"})
-    proc { query_parser.parse_query("a=a;b=b;c=c") }.must_raise Rack::QueryParser::QueryLimitError
-    proc { query_parser.parse_nested_query("a=a;b=b;c=c", ';') }.must_raise Rack::QueryParser::QueryLimitError
-    proc { query_parser.parse_query("b[]=a;b[]=b;b[]=c") }.must_raise Rack::QueryParser::QueryLimitError
   end
 end
